require 'spec_helper'

describe 'PLSql' do
  before do
    @pl_sql = Object.new
    @pl_sql.extend(ActiveRecord::Jdbc::PLSql)

    @parameters = ['test', :integer]
    @named_parameters = {test1: 'test', test2: :integer}
  end

  describe '#parse_input_parameters' do
    it 'returns an input parameter array when parameters are named' do
      input_parameters = @pl_sql.parse_input_parameters(@named_parameters)
      expect(input_parameters.size).to be 1
      expect(input_parameters.keys.first).to eq :test1
      expect(input_parameters.values.first).to eq 'test'
    end

    it 'returns an input parameter array when parameters are unnamed' do
      input_parameters = @pl_sql.parse_input_parameters(@parameters)
      expect(input_parameters.size).to be 1
      expect(input_parameters.keys.first).to eq 1
      expect(input_parameters.values.first).to eq 'test'
    end
  end

  describe '#parse_output_parameters' do
    it 'returns an input parameter array when parameters are named' do
      output_parameters = @pl_sql.parse_output_parameters(@named_parameters)
      expect(output_parameters.size).to be 1
      expect(output_parameters.keys.first).to eq :test2
      expect(output_parameters.values.first).to be :integer
    end

    it 'returns an input parameter array when parameters are unnamed' do
      output_parameters = @pl_sql.parse_output_parameters(@parameters)
      expect(output_parameters.size).to be 1
      expect(output_parameters.keys.first).to be 2
      expect(output_parameters.values.first).to be :integer
    end
  end
end